@@ -14,7 +14,7 @@ using namespace Solid::Backends::UDisks2;
 GenericInterface::GenericInterface(Device *device)
     : DeviceInterface(device)
 {
-    connect(device, SIGNAL(propertyChanged(QMap<QString, int>)), this, SIGNAL(propertyChanged(QMap<QString, int>)));
+    connect(device, &Device::propertyChanged, this, &GenericInterface::propertyChanged);
 }
 
 GenericInterface::~GenericInterface()
