@@ -8,12 +8,14 @@
 #include "udisksstorageaccess.h"
 #include "udisks2.h"
 #include "udisks_debug.h"
+#include "udisksutils.h"
 
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusMetaType>
 #include <QDir>
 #include <QGuiApplication>
+#include <QMetaObject>
 #include <QWindow>
 
 #include <config-solid.h>
@@ -53,14 +55,12 @@ StorageAccess::StorageAccess(Device *device)
     , m_repairInProgress(false)
     , m_passphraseRequested(false)
 {
-    qDBusRegisterMetaType<AvailableAnswer>();
-
     connect(device, SIGNAL(changed()), this, SLOT(checkAccessibility()));
     updateCache();
 
     // Delay connecting to DBus signals to avoid the related time penalty
     // in hot paths such as predicate matching
-    QTimer::singleShot(0, this, SLOT(connectDBusSignals()));
+    QMetaObject::invokeMethod(this, &StorageAccess::connectDBusSignals, Qt::QueuedConnection);
 }
 
 StorageAccess::~StorageAccess()
@@ -91,7 +91,7 @@ bool StorageAccess::isAccessible() const
         if (path.isEmpty() || path == QLatin1String("/")) {
             return false;
         }
-        Device holderDevice(path);
+        Device holderDevice(m_device->manager(), path);
         return holderDevice.isMounted();
     }
 
@@ -193,7 +193,7 @@ static QString baseMountPoint(const QByteArray &dev)
             struct libmnt_iter *itr = mnt_new_iter(MNT_ITER_BACKWARD);
             struct libmnt_fs *fs;
 
-            const QByteArray devicePath = dev.endsWith('\x00') ? dev.chopped(1) : dev;
+            const QByteArray devicePath = Utils::sanitizeValue(dev);
 
             while (mnt_table_next_fs(table, itr, &fs) == 0) {
                 if (mnt_fs_get_srcpath(fs) == devicePath //
@@ -223,14 +223,10 @@ QString StorageAccess::filePath() const
         if (path.isEmpty() || path == QLatin1String("/")) {
             return QString();
         }
-        Device holderDevice(path);
+        Device holderDevice(m_device->manager(), path);
         const auto mntPoints = qdbus_cast<QByteArrayList>(holderDevice.prop(QStringLiteral("MountPoints")));
         if (!mntPoints.isEmpty()) {
-            QByteArray first = mntPoints.first();
-            if (first.endsWith('\x00')) {
-                first.chop(1);
-            }
-            return QFile::decodeName(first); // FIXME Solid doesn't support multiple mount points
+            return QFile::decodeName(Utils::sanitizeValue(mntPoints.first())); // FIXME Solid doesn't support multiple mount points
         } else {
             return QString();
         }
@@ -241,11 +237,7 @@ QString StorageAccess::filePath() const
         return {};
     }
 
-    QByteArray first = mntPoints.first();
-    if (first.endsWith('\x00')) {
-        first.chop(1);
-    }
-    const QString potentialMountPoint = QFile::decodeName(first);
+    const QString potentialMountPoint = QFile::decodeName(Utils::sanitizeValue(mntPoints.first()));
 
     if (mntPoints.size() == 1) {
         return potentialMountPoint;
@@ -324,7 +316,6 @@ void StorageAccess::slotDBusReply(const QDBusMessage &reply)
             mount();
         } else { // Don't broadcast setupDone unless the setup is really done. (Fix kde#271156)
             m_setupInProgress = false;
-            m_device->invalidateCache();
             m_device->broadcastActionDone(QStringLiteral("setup"));
 
             checkAccessibility();
@@ -340,7 +331,7 @@ void StorageAccess::slotDBusReply(const QDBusMessage &reply)
             // try to "eject" (aka safely remove) from the (parent) drive, e.g. SD card from a reader
             QString drivePath = m_device->drivePath();
             if (!drivePath.isEmpty() || drivePath != QStringLiteral("/")) {
-                Device drive(drivePath);
+                Device drive(m_device->manager(), drivePath);
                 QDBusConnection c = QDBusConnection::systemBus();
 
                 if (drive.prop(QStringLiteral("MediaRemovable")).toBool() //
@@ -365,7 +356,6 @@ void StorageAccess::slotDBusReply(const QDBusMessage &reply)
             }
 
             m_teardownInProgress = false;
-            m_device->invalidateCache();
             m_device->broadcastActionDone(QStringLiteral("teardown"));
 
             checkAccessibility();
